brintos

brintos / llvm-project-archived public Read only

0
0
Text · 1.3 KiB · 66704a3 Raw
35 lines · plain
1// RUN: %clang_cc1 -fsyntax-only -verify %s2// RUN: %clang_cc1 -fsyntax-only -fcuda-is-device -verify=dev,expected %s3 4#include "Inputs/cuda.h"5 6__host__ void h1h(void);7__device__ void h1d(void); // expected-note {{candidate function not viable: call to __device__ function from __host__ function}}8__host__ __device__ void h1hd(void);9__global__ void h1g(void);10 11struct h1ds { // expected-note {{requires 1 argument}}12	      // expected-note@-1 {{candidate constructor (the implicit move constructor) not viable}}13  __device__ h1ds(); // expected-note {{candidate constructor not viable: call to __device__ function from __host__ function}}14};15 16__host__ void h1(void) {17  h1h();18  h1d(); // expected-error {{no matching function}}19  h1hd();20  h1g<<<1, 1>>>();21  h1ds x; // expected-error {{no matching constructor}}22}23 24__host__ void d1h(void); // expected-note {{candidate function not viable: call to __host__ function from __device__ function}}25__device__ void d1d(void);26__host__ __device__ void d1hd(void);27__global__ void d1g(void);28 29__device__ void d1(void) {30  d1h(); // expected-error {{no matching function}}31  d1d();32  d1hd();33  d1g<<<1, 1>>>(); // expected-error {{kernel launch from __device__ or __global__ function requires relocatable device code (i.e. requires -fgpu-rdc)}}34}35